pub struct SendRequestSeed<'a> { /* private fields */ }Expand description
Registry-driven deserializer for SendRequest.
Unknown provider option keys are ignored so a queued payload can carry options for transports that are not installed in a particular worker.
Implementations
Sourceimpl<'a> SendRequestSeed<'a>
impl<'a> SendRequestSeed<'a>
Sourcepub const fn new(registry: &'a TransportOptionRegistry) -> Self
pub const fn new(registry: &'a TransportOptionRegistry) -> Self
Create a request seed backed by registry.